Visualisation
=============

s2dverification contains a set of functions to plot data at every stage of the 
verification process, mostly based directly on R graphics plotting tools.
These functions are essential to:
 - Quickly inspect the results of a newly produced experiment, i.e. to check 
the physical consistency of the results.
 - Assess the added value of a new prediction system, i.e. to compare new 
results with a reference (observation or other experiment).
 - Assess visually the significance of results, i.e. to display in a 
user-friendly way confidence intervals and other statistics.

The visualisation functions, most with a name following the pattern 
`Plot*()`, can be grouped as a function of the kind of plot they provide: 
 - [**Plotting time series**](#time_series): `PlotClim()`, `PlotAno()`, 
`PlotVsLtime()`, `Plot2VarsVsLTime()` and `PlotACC()`.
 - [**Plotting 2-dimensional fields**](#2d_fields): `PlotEquiMap()`, 
`PlotStereoMap()`, `AnimVsLTime()`, `PlotSection()`.

Next an explanation of which situations they fit the best, details of the 
options they provide and short examples of usage. 

To master these functions it is convenient to have in mind the common array 
dimension structure used throughout in s2dverification and how it evolves as 
the data objects go through the statistics and verification stages. For that 
you can review the introduction in [**Data retrieval**](data_retrieval.md) and 
the sections [**Statistics**](statistics.md) and 
[**Verification**](verification.md).

Plotting time series<a name="time_series"></a>
--------------------

All the functions devoted to plotting time series have some common traits and
parameters:
 - All of them generate plots and save them to post-script (.ps, .eps) 
files the path and file name of which you have to provide to the `fileout` 
parameter. 
 - 

`PlotClim()` takes as inputs an experimental and an observational array of 2 
to 3 dimensions each:
```r
  c(n. of datasets, n. of members, n. of lead-times)
```
the second one being optional. This means that the latitude and longitude 
dimensions must have been removed either because working on area-averages or
because working on a single grid point and that the starting dates dimension
must have also been removed either because willing to plot data of a single
starting date or because working on averages across starting dates, i.e. 
climatologies (see [**Statistics**](statistics.md)).

The members of a same experiment or observation are plotted with the same 
colour whereas the different experiments and observations are plotted with
different colours.

As seen in [**Normalizing fields**](statistics.md#normalizing):
```r
PlotClim(clim$clim_exp, clim$clim_obs, monini = 12,
         toptitle = "Per-pair 'tas' climatologies over the Atlantic region.",
         ytitle = "K",
         listexp = c('Experiment A', 'Experiment B'),
         listobs = c('Observation X'),
         fileout = "stat_clim_expA_expB_obsX.eps")
```
<img src="stat_clim_expA_expB_obsX.png" width="600" />



Plotting 2-dimensional fields<a name="2d_fields"></a>
-----------------------------



